@@ -1,9 +1,10 @@
 import logging
 
+from .models import Tag
 from .response import Response
 from .spec import SpecTree
 
-__all__ = ["SpecTree", "Response"]
+__all__ = ["SpecTree", "Response", "Tag"]
 
 # setup library logging
 logging.getLogger(__name__).addHandler(logging.NullHandler())
